[vinagre] Make vinagre_plugin_get_context_groups return a list of groups.



commit 58219e9de84187f841872a5ad7c17167b9937d7b
Author: Jonh Wendell <jwendell gnome org>
Date:   Tue Aug 11 15:21:25 2009 -0300

    Make vinagre_plugin_get_context_groups return a list of groups.
    
    This enables plugins to have more than 1 OptionGroup.

 vinagre/vinagre-plugin.c |   16 ++++++++--------
 vinagre/vinagre-plugin.h |    4 ++--
 2 files changed, 10 insertions(+), 10 deletions(-)
---
diff --git a/vinagre/vinagre-plugin.h b/vinagre/vinagre-plugin.h
index def7300..41830a6 100644
--- a/vinagre/vinagre-plugin.h
+++ b/vinagre/vinagre-plugin.h
@@ -74,7 +74,7 @@ struct _VinagrePluginClass
 
 
   /* Virtual methods specific to 'engine' plugins */
-  GOptionGroup	*(*get_context_group)		(VinagrePlugin *plugin);
+  GSList	*(*get_context_groups)		(VinagrePlugin *plugin);
   const gchar	*(*get_protocol)		(VinagrePlugin *plugin);
   gchar		**(*get_public_description)	(VinagrePlugin *plugin);
   gint		(*get_default_port)		(VinagrePlugin *plugin);
@@ -123,7 +123,7 @@ void 		 vinagre_plugin_update_ui		(VinagrePlugin *plugin,
 gboolean	 vinagre_plugin_is_configurable		(VinagrePlugin *plugin);
 GtkWidget	*vinagre_plugin_create_configure_dialog	(VinagrePlugin *plugin);
 
-GOptionGroup	*vinagre_plugin_get_context_group	(VinagrePlugin *plugin);
+GSList		*vinagre_plugin_get_context_groups	(VinagrePlugin *plugin);
 const gchar	*vinagre_plugin_get_protocol		(VinagrePlugin *plugin);
 gchar		**vinagre_plugin_get_public_description	(VinagrePlugin *plugin);
 gint		 vinagre_plugin_get_default_port	(VinagrePlugin *plugin);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/vinagre/vinagre-plugin.c b/vinagre/vinagre-plugin.c
index eb23e30..99acfc2 100644
--- a/vinagre/vinagre-plugin.c
+++ b/vinagre/vinagre-plugin.c
@@ -61,8 +61,8 @@ create_configure_dialog	(VinagrePlugin *plugin)
   return NULL;
 }
 
-static GOptionGroup *
-default_context_group (VinagrePlugin *plugin)
+static GSList *
+default_context_groups (VinagrePlugin *plugin)
 {
   return NULL;
 }
@@ -187,7 +187,7 @@ vinagre_plugin_class_init (VinagrePluginClass *klass)
 	klass->activate = dummy;
 	klass->deactivate = dummy;
 	klass->update_ui = dummy;
-	klass->get_context_group = default_context_group;
+	klass->get_context_groups = default_context_groups;
 	klass->get_protocol = default_get_protocol;
 	klass->get_public_description = default_get_public_description;
 	klass->get_default_port = default_get_default_port;
@@ -396,18 +396,18 @@ vinagre_plugin_create_configure_dialog (VinagrePlugin *plugin)
 }
 
 /**
- * vinagre_plugin_get_context_group
+ * vinagre_plugin_get_context_groups
  * @plugin: a #VinagrePlugin
  *
  *
  * Returns: a context group to be used on command line, if available
  */
-GOptionGroup *
-vinagre_plugin_get_context_group (VinagrePlugin *plugin)
+GSList *
+vinagre_plugin_get_context_groups (VinagrePlugin *plugin)
 {
   g_return_val_if_fail (VINAGRE_IS_PLUGIN (plugin), NULL);
 	
-  return VINAGRE_PLUGIN_GET_CLASS (plugin)->get_context_group (plugin);
+  return VINAGRE_PLUGIN_GET_CLASS (plugin)->get_context_groups (plugin);
 }
 
 /**
@@ -396,18 +396,18 @@ vinagre_plugin_create_configure_dialog (VinagrePlugin *plugin)
  *
  *
- * Returns: a context group to be used on command line, if available
+ * Returns: a list of context groups to be used on command line, if available
  */